aboutsummaryrefslogtreecommitdiff
path: root/third_party/chromium/base/json/json_parser.h
diff options
context:
space:
mode:
Diffstat (limited to 'third_party/chromium/base/json/json_parser.h')
-rw-r--r--third_party/chromium/base/json/json_parser.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/third_party/chromium/base/json/json_parser.h b/third_party/chromium/base/json/json_parser.h
index fc04594..5bdec58 100644
--- a/third_party/chromium/base/json/json_parser.h
+++ b/third_party/chromium/base/json/json_parser.h
@@ -8,6 +8,7 @@
#include <stddef.h>
#include <stdint.h>
+#include <memory>
#include <string>
#include "base/base_export.h"
@@ -50,7 +51,7 @@ class BASE_EXPORT JSONParser {
// Parses the input string according to the set options and returns the
// result as a Value owned by the caller.
- Value* Parse(const StringPiece& input);
+ std::unique_ptr<Value> Parse(StringPiece input);
// Returns the error code.
JSONReader::JsonParseError error_code() const;
@@ -133,7 +134,7 @@ class BASE_EXPORT JSONParser {
size_t length_;
// The copied string representation. NULL until Convert() is called.
// Strong. scoped_ptr<T> has too much of an overhead here.
std::string* string_;
};
@@ -133,7 +134,7 @@ class BASE_EXPORT JSONParser {
size_t length_;
// The copied string representation. NULL until Convert() is called.
- // Strong. scoped_ptr<T> has too much of an overhead here.
+ // Strong. std::unique_ptr<T> has too much of an overhead here.
std::string* string_;
};